# Mypy Type Check Coverage Summary

Summary from index
File | Imprecision | Lines
--- | --- | ---
Total | 18.74% imprecise | 2562 LOC
ecr | 0.00% imprecise | 4 LOC
ecr.__main__ | 16.99% imprecise | 206 LOC
ecr.commands | 0.00% imprecise | 35 LOC
ecr.commands.cmd_cd | 32.14% imprecise | 28 LOC
ecr.commands.cmd_clean | 10.53% imprecise | 19 LOC
ecr.commands.cmd_clear | 17.07% imprecise | 41 LOC
ecr.commands.cmd_cls | 16.67% imprecise | 12 LOC
ecr.commands.cmd_debug | 23.53% imprecise | 85 LOC
ecr.commands.cmd_edit | 34.04% imprecise | 47 LOC
ecr.commands.cmd_exit | 20.00% imprecise | 10 LOC
ecr.commands.cmd_init | 23.53% imprecise | 34 LOC
ecr.commands.cmd_new | 33.33% imprecise | 48 LOC
ecr.commands.cmd_now | 25.00% imprecise | 32 LOC
ecr.commands.cmd_pwd | 15.38% imprecise | 13 LOC
ecr.commands.cmd_reload | 26.92% imprecise | 26 LOC
ecr.commands.cmd_run | 33.33% imprecise | 135 LOC
ecr.commands.cmd_status | 29.17% imprecise | 24 LOC
ecr.commands.cmd_template | 25.64% imprecise | 117 LOC
ecr.commands.cmd_test | 37.50% imprecise | 88 LOC
ecr.commands.cmd_version | 12.50% imprecise | 16 LOC
ecr.commands.helper | 12.50% imprecise | 40 LOC
ecr.core | 0.00% imprecise | 3 LOC
ecr.core._Runner | 8.70% imprecise | 138 LOC
ecr.core._WorkItem | 10.11% imprecise | 89 LOC
ecr.core._WorkManager | 5.09% imprecise | 373 LOC
ecr.core._manager | 14.71% imprecise | 34 LOC
ecr.core.defaultData | 0.00% imprecise | 108 LOC
ecr.core.globalData | 0.00% imprecise | 12 LOC
ecr.core.manager | 0.00% imprecise | 6 LOC
ecr.core.path | 0.00% imprecise | 65 LOC
ecr.helper | 10.34% imprecise | 58 LOC
ecr.lib | 0.00% imprecise | 0 LOC
ecr.lib.console | 43.48% imprecise | 23 LOC
ecr.lib.judger | 19.64% imprecise | 56 LOC
ecr.lib.runner | 0.00% imprecise | 8 LOC
ecr.log | 24.59% imprecise | 61 LOC
ecr.shared | 3.77% imprecise | 53 LOC
ecr.template | 0.00% imprecise | 4 LOC
ecr.template._Template | 9.09% imprecise | 66 LOC
ecr.template.path | 0.00% imprecise | 13 LOC
ecr.types | 0.00% imprecise | 13 LOC
ecr.ui | 0.00% imprecise | 13 LOC
ecr.ui.cli | 35.82% imprecise | 67 LOC
ecr.ui.color | 47.62% imprecise | 21 LOC
ecr.ui.command | 16.67% imprecise | 24 LOC
ecr.ui.helper | 0.00% imprecise | 1 LOC
ecr.ui.helper.BashLexer | 50.48% imprecise | 105 LOC
ecr.ui.helper.PathCompleter | 43.18% imprecise | 88 LOC